<?php
/**
 * Class Medias ToolBox Core
 * The file that defines the core plugin class
 *
 * @author NeosLab <contact@neoslab.com>
 * @link https://neoslab.com
 * @version 1.5.0
 * @package Medias_ToolBox
*/
class Medias_ToolBox_Core
{
	/**
	 * The loader that's responsible for maintaining and registering all hooks that power the plugin
	*/
	protected $loader;

	/**
	 * The unique identifier of this plugin
	*/
	protected $plugin_name;

	/**
	 * The current version of the plugin
	*/
	protected $version;

	/**
	 * Define the core functionality of the plugin
	*/
	public function __construct()
	{
		$this->plugin_name = MTB_PLUGIN_IDENTIFIER;
		$this->version = MTB_PLUGIN_VERSION;
		$this->load_dependencies();
		$this->set_locale();
		$this->define_admin_hooks();
	}

	/**
	 * Load the required dependencies for this plugin include the following files that make up the plugin:
	 * - Medias_ToolBox_Loader ~ Orchestrates the hooks of the plugin
	 * - Medias_ToolBox_i18n ~ Defines internationalization functionality
	 * - Medias_ToolBox_Admin ~ Defines all hooks for the admin area
	 * - Medias_ToolBox_Public ~ Defines all hooks for the public side of the site
	 *
	 * Create an instance of the loader which will be used to register the hooks with WordPress
	*/
	private function load_dependencies()
	{
		/**
		 * The class responsible for orchestrating the actions and filters of the core plugin
		*/
		require_once plugin_dir_path(dirname(__FILE__)).'includes/class-medias-toolbox-loader.php';

		/**
		 * The class responsible for defining internationalization functionality of the plugin
		*/
		require_once plugin_dir_path(dirname(__FILE__)).'includes/class-medias-toolbox-i18n.php';

		/**
		 * The class responsible for defining all actions that occur in the admin area
		*/
		require_once plugin_dir_path(dirname(__FILE__)).'admin/class-medias-toolbox-admin.php';

		/**
		 * Callback Loader
		*/
		$this->loader = new Medias_ToolBox_Loader();
	}

	/**
	 * Define the locale for this plugin for internationalization
	 * Uses the Medias_ToolBox_i18n class in order to set the domain and to register the hook with WordPress
	*/
	private function set_locale()
	{
		$plugin_i18n = new Medias_ToolBox_i18n();
		$this->loader->add_action('plugins_loaded', $plugin_i18n, 'load_plugin_textdomain');
	}

	/**
	 * Register all of the hooks related to the admin area functionality of the plugin
	*/
	private function define_admin_hooks()
	{
		$plugin_admin = new Medias_ToolBox_Admin($this->get_plugin_name(), $this->get_version());

		$allowed = array('medias-toolbox-admin', 'medias-toolbox-compress', 'medias-toolbox-renamer', 'medias-toolbox-about');
		if((isset($_GET['page'])) && (in_array($_GET['page'], $allowed)))
		{
			$this->loader->add_action('admin_enqueue_scripts', $plugin_admin, 'enqueue_backend_styles');
			$this->loader->add_action('admin_enqueue_scripts', $plugin_admin, 'enqueue_backend_scripts');
		}

		$this->loader->add_action('admin_enqueue_scripts', $plugin_admin, 'enqueue_backend_standalone');
		$this->loader->add_action('admin_menu', $plugin_admin, 'return_admin_menu');
		$this->loader->add_action('init', $plugin_admin, 'return_update_options');
		$this->loader->add_action('init', $plugin_admin, 'return_proceed_medias');
		$this->loader->add_filter('sanitize_file_name', $plugin_admin, 'return_rename_upload');
	}

	/**
	 * Run the loader to execute all of the hooks with WordPress
	*/
	public function run()
	{
		$this->loader->run();
	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality
	*/
	public function get_plugin_name()
	{
		return $this->plugin_name;
	}

	/**
	 * The reference to the class that orchestrates the hooks with the plugin
	*/
	public function get_loader()
	{
		return $this->loader;
	}

	/**
	 * Retrieve the version number of the plugin
	*/
	public function get_version()
	{
		return $this->version;
	}
}

?>
